<template>
  <el-dialog
    top="10vh"
    width="75%"
    :fullscreen="isFullScreen"
    :close-on-click-modal="false"
    :visible.sync="visible"
  >
    <template slot="title">
      <i
        :class="isFullScreen ? 'icon-zuixiaohua' : 'icon-quanpingzuidahua'"
        style="position: absolute; right: 52px; float: right"
        @click="fullscreen"
      >
      </i>
      <span>创建主生产计划</span>
    </template>

    <el-form :model="dataForm" :rules="dataRule" ref="dataForm" class="l-mes">
      <div class="avue-crud">
        <el-table
          border
          :data="dataForm.customer"
          style="width: 100%"
          class="mps-table"
          height="500px"
        >
          <el-table-column
            header-align="center"
            align="center"
            label="客户订单编号"
            min-width="130px"
          >
            <template slot-scope="scope">
              <el-form-item>{{ scope.row.contractNo }}</el-form-item>
            </template>
          </el-table-column>
          <el-table-column
            header-align="center"
            align="center"
            label="零件号"
            min-width="130"
          >
            <template slot-scope="scope">
              <el-form-item>{{ scope.row.partNo }}</el-form-item>
            </template>
          </el-table-column>
          <el-table-column
            header-align="center"
            align="center"
            label="零件名称"
            width="200px"
            show-overflow-tooltip
          >
            <template slot-scope="scope">
              <el-form-item class="inline-el-hidden">{{
                scope.row.productName
              }}</el-form-item>
            </template>
          </el-table-column>
          <el-table-column
            header-align="center"
            align="center"
            label="需求数量"
            width="90px"
          >
            <template slot-scope="scope">
              <el-form-item>{{ scope.row.buyQtyDue }}</el-form-item>
            </template>
          </el-table-column>
          <!-- <el-table-column
            header-align="center"
            align="center"
            label="已计划数量"
          >
            <template slot-scope="scope">
              <el-form-item>{{ scope.row.requireNumber }}</el-form-item>
            </template>
          </el-table-column> -->
          <el-table-column
            prop="remainderRequired"
            header-align="center"
            align="center"
            label="本次计划数量"
          >
            <template scope="scope">
              <el-form-item>{{ scope.row.qtyPlaned }}</el-form-item>
              <!-- <el-form-item
                :prop="'customer.' + scope.$index"
                :rules="rules.qtyPlaned"
              >
                <el-input
                  v-model="scope.row.qtyPlaned"
                  placeholder="请输入本次计划数量"
                ></el-input> -->
              </el-form-item>
            </template>
          </el-table-column>
          <el-table-column
            header-align="center"
            align="center"
            label="单位"
          >
            <template slot-scope="scope">
              <span>{{ scope.row.otcUnit }}</span>
            </template>
          </el-table-column>
          <el-table-column
            prop="manufactureAttr"
            header-align="center"
            align="center"
            label="制造属性"
          >
            <template scope="scope">
              <el-form-item :prop="'manufactureAttr.' + scope.$index">
                <el-select
                  v-model="scope.row.manufactureAttr"
                  placeholder=""
                  disabled
                  style="width: 100%"
                >
                  <el-option
                    v-for="item in manufactureAttrs"
                    :key="item.value"
                    :label="item.label"
                    :value="item.value"
                  />
                </el-select>
              </el-form-item>
            </template>
          </el-table-column>
          <el-table-column
            header-align="center"
            align="center"
            label="需求日期"
          >
            <template slot-scope="scope">
              <el-form-item>{{ scope.row.deliveryDate }}</el-form-item>
            </template>
          </el-table-column>
          <el-table-column
            header-align="center"
            align="center"
            show-overflow-tooltip
            label="备注"
            min-width="140"
          >
            <template slot-scope="scope">
              <el-form-item>
                <el-input v-model="scope.row.remark" placeholder=""></el-input>
              </el-form-item>
            </template>
          </el-table-column>
        </el-table>
      </div>
    </el-form>

    <div slot="footer" class="dialog-footer">
      <el-button type="info" @click="visible = false">取消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`dataFormSubmit`"
        >确定</el-button
      >
    </div>
    <!--<OutputBatch
      :currshowlist.sync="showOutputBatch"
      :outPutBatchList="outPutBatchList"
      :customerOrder="currCustomerOrder"
    >
    </OutputBatch>-->
  </el-dialog>
</template>

<script>
import { validateQtyPlaned } from '@/util/validate'
import {
  createMasterProductionSchedule,
  checkSchedule
} from '../../../api/plan/customerorder'
import { remote } from '@/api/admin/dict'

export default {
  data() {
    return {
      isFullScreen: false,
      visible: true,
      dataForm: {
        customer: []
      },
      dataRule: {},
      isSubmit: false,
      manufactureAttrs: [],
      outPutBatchList: [],
      currCustomerOrder: null,
      showOutputBatch: false
    }
  },
  created() {
    this.getManufactureAttrs()
  },
  components: {},
  methods: {
    getManufactureAttrs() {
      remote('manufacture_attr_type').then((response) => {
        if (response.data.code === 0) {
          this.manufactureAttrs = response.data.data
        } else {
          this.manufactureAttrs = []
        }
      })
    },
    init(customer) {
      this.visible = true
      // 查询出每个客户订单对应的客户订单预留的数量
      // TODO
      this.$nextTick(() => {
        const customerList = []
        this.dataForm.customer = []
        const _that = this
        customer.forEach((item) => {
          const outPutBatchList = []
          _that.$set(item, 'outPutBatchList', outPutBatchList)
          customerList.push(item)
        })
        this.dataForm.customer = JSON.parse(JSON.stringify(customerList))
        this.dataForm.customer.forEach(item=>{
            item.qtyPlaned=item.buyQtyDue
        })
      })
    },
    dataFormSubmit() {
      this.isSubmit = true
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          console.log(this.dataForm.customer);
          return
          checkSchedule(this.dataForm.customer)
            .then((res) => {
              if (res.data.data.success) {
                createMasterProductionSchedule(this.dataForm.customer)
                  .then((res) => {
                    this.$message.success('主生产计划创建成功')
                    this.visible = false
                    this.isSubmit = false
                    this.$emit('refreshDataList', 1)
                    this.$router.push({
                      path: '../masterproductionschedule/index'
                    })
                  })
                  .catch(() => {
                    this.isSubmit = false
                  })
              } else {
                this.$message.error(res.data.data.message)
              }
            })
            .finally(() => {
              this.isSubmit = false
            })
        } else {
          this.isSubmit = false
        }
      })
    },
    // 全屏
    fullscreen() {
      this.isFullScreen = !this.isFullScreen
    }
  },
  computed: {
    rules: function() {
      return {
        qtyPlaned: [{ validator: validateQtyPlaned, trigger: 'blur' }]
      }
    }
  }
}
</script>
<style scoped>
.mps-table .el-table__row > td {
  border: none;
}

.mps-table::before {
  height: 0px;
}
/*
字符串过长时，隐藏显示省略号
*/
.inline-el-hidden {
  display: block;
  width: 93%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  margin: 0 auto;
}
</style>
